@@ -18,6 +18,7 @@ use Minilla::Logger;
 use Minilla::Metadata;
 use Minilla::WorkDir;
 use Minilla::ReleaseTest;
+use Minilla::Unsupported;
 use Minilla::ModuleMaker::ModuleBuild;
 use Minilla::ModuleMaker::ModuleBuildTiny;
 use Minilla::ModuleMaker::ExtUtilsMakeMaker;
@@ -132,6 +133,12 @@ sub authors {
     $self->config->{authors} || $self->metadata->authors;
 }
 
+sub unsupported {
+    my $self = shift;
+    my $unsupported = $self->config->{unsupported} || {};
+    return Minilla::Unsupported->new(%$unsupported);
+}
+
 sub abstract {
     my $self = shift;
     if (my $abstract_from = $self->config->{abstract_from}) {
